@@ -9,3 +9,5 @@ pub mod nimiq;
 pub mod ravencoin;
 pub mod siacoin;
 pub mod chia;
+pub mod turtl;
+pub mod starcoin;
